adso
====

**A topic modelling library built on top of scipy/numpy and nltk.**

install
^^^^^^^

To install::

    pip install adso

config
^^^^^^

adso need to write some files to disk.
As default adso uses the ``~/.adso`` folder, but it can be change setting the enviromental variable ``ADSODIR``.

documentation
^^^^^^^^^^^^^

Documentation with examples is hosted on [GitHub Pages](https://tnto.github.io/adso/index.html)

Some examples on how to use adso are also available in ``tests`` and ``examples`` folders.


